"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SocketIoClientStrategy = void 0;
const microservices_1 = require("@nestjs/microservices");
class SocketIoClientStrategy extends microservices_1.Server {
    constructor(client, logger) {
        super();
        this.client = client;
        this.logger = logger;
    }
    /**
     * This method is triggered when you run "app.listen()".
     */
    listen(callback) {
        this.client.on('connection', () => {
            this.logger.log('connection', 'SocketIoClientStrategy');
        });
        this.client.on('error', (error) => {
            if (error instanceof Error) {
                this.logger.error(error.message, 'SocketIoClientStrategy');
            }
            else {
                this.logger.error(error);
            }
        });
        this.messageHandlers.forEach((handler, pattern) => {
            this.client.on(pattern, (data) => {
                handler(data, this.client);
            });
        });
        callback();
    }
    /**
     * This method is triggered on application shutdown.
     */
    close() {
        this.client.disconnect();
    }
}
exports.SocketIoClientStrategy = SocketIoClientStrategy;
//# sourceMappingURL=socket-io-client.strategy.js.map